Ray

Struct Ray 

#[repr(C)]
pub struct Ray { pub origin: Vec3A, pub direction: Vec3A, pub inv_direction: Vec3A, pub tmin: f32, pub tmax: f32, }
A struct representing a ray in 3D space.

Fields

origin: Vec3A

The starting point of the ray.

direction: Vec3A

The direction vector of the ray.

inv_direction: Vec3A

The inverse of the direction vector components. Used to avoid division in ray/aabb tests. Seems to improve performance in some cases on the cpu, but not the gpu in some others.

tmin: f32

The minimum t (distance) value for intersection tests.

tmax: f32

The maximum t (distance) value for intersection tests.

Implementations

Source

impl Ray

pub fn new(origin: Vec3A, direction: Vec3A, min: f32, max: f32) -> Self

Creates a new Ray with the given origin, direction, and t (distance) range.

pub fn new_inf(origin: Vec3A, direction: Vec3A) -> Self

Creates a new infinite Ray with the given origin, direction.